@@ -169,15 +169,19 @@ class BinarySemSegImgPatchDataset(PatchedImgDataset):
                 )
 
         if dspec.get('bbox_crop'):
+            copy = img_obj.copy()
             img_obj.array, img_obj.ground_truth, img_obj.mask = _imgutils.masked_bboxcrop(img_obj.array,
                                                                                           img_obj.ground_truth)
-            dspec['has_mask'] = True
+
+            if img_obj.array.shape[0] < dspec['patch_shape'][0] or img_obj.array.shape[1] < dspec['patch_shape'][1]:
+                _warn.warn(f"BBOX crop reversing for {dspec['name']}:{img_obj.file}, shape: {img_obj.array.shape}")
+                img_obj = copy.copy()
 
         if dspec.get('resize'):
             img_obj.array = _imgutils.resize(img_obj.array, dspec['resize'])
             img_obj.ground_truth = _imgutils.resize(img_obj.ground_truth, dspec['resize'])
 
-            if dspec.get('has_mask'):
+            if img_obj.mask is not None:
                 img_obj.mask = _imgutils.resize(img_obj.mask, dspec['resize'])
 
         """Must binarize after resize"""
